import { NgComponentOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, inject, Injector, Component, ChangeDetectionStrategy, NgModule, Injectable, APP_INITIALIZER } from '@angular/core';
import * as i1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i2 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { ContentContainerComponentHarness, HarnessPredicate } from '@angular/cdk/testing';
import { MatButtonHarness } from '@angular/material/button/testing';
import { MatDialogHarness } from '@angular/material/dialog/testing';
import { firstValueFrom } from 'rxjs';
import { MatIconHarness } from '@angular/material/icon/testing';
import { MatIconRegistry } from '@angular/material/icon';
import { DomSanitizer } from '@angular/platform-browser';

/**
 * Injection token for a custom dialog component to receive input. See {@link DialogData.slDialogData}.
 */
const SL_DIALOG_DATA = new InjectionToken('SL_DIALOG_DATA');
/**
 * The {@link DialogButton.value} for the default "OK" button that is used if you do not specify any custom buttons for your dialog.
 */
const DEFAULT_OK_VALUE = Symbol('OK');
class DialogComponent {
    constructor() {
        this.data = inject(MAT_DIALOG_DATA);
        this.componentInjector = Injector.create({
            providers: [{ provide: SL_DIALOG_DATA, useValue: this.data.slDialogData }],
            parent: inject(Injector),
        });
        this.data.buttons ??= [{ text: 'OK', value: DEFAULT_OK_VALUE }];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: DialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.0.4", type: DialogComponent, isStandalone: true, selector: "sl-dialog", ngImport: i0, template: "<h2 mat-dialog-title>{{ data.title ?? data.component?.title }}</h2>\n\n<mat-dialog-content class=\"mat-typography\">\n  @if (data.text) {\n    <p>{{ data.text }}</p>\n  }\n  @if (data.component) {\n    <ng-container\n      *ngComponentOutlet=\"data.component; injector: componentInjector\"\n    />\n  }\n</mat-dialog-content>\n\n<mat-dialog-actions align=\"end\">\n  @for (button of data.buttons; track button) {\n    <button\n      mat-button\n      [mat-dialog-close]=\"button.value ?? button.text\"\n      [color]=\"button.color ?? 'primary'\"\n    >\n      {{ button.text }}\n    </button>\n  }\n</mat-dialog-actions>\n", styles: ["mat-dialog-actions button{text-transform:uppercase}\n"], dependencies: [{ kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i1.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i2.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i2.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i2.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i2.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: NgComponentOutlet, selector: "[ngComponentOutlet]", inputs: ["ngComponentOutlet", "ngComponentOutletInputs", "ngComponentOutletInjector", "ngComponentOutletContent", "ngComponentOutletNgModule", "ngComponentOutletNgModuleFactory"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: DialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sl-dialog', standalone: true, imports: [MatButtonModule, MatDialogModule, NgComponentOutlet], changeDetection: ChangeDetectionStrategy.OnPush, template: "<h2 mat-dialog-title>{{ data.title ?? data.component?.title }}</h2>\n\n<mat-dialog-content class=\"mat-typography\">\n  @if (data.text) {\n    <p>{{ data.text }}</p>\n  }\n  @if (data.component) {\n    <ng-container\n      *ngComponentOutlet=\"data.component; injector: componentInjector\"\n    />\n  }\n</mat-dialog-content>\n\n<mat-dialog-actions align=\"end\">\n  @for (button of data.buttons; track button) {\n    <button\n      mat-button\n      [mat-dialog-close]=\"button.value ?? button.text\"\n      [color]=\"button.color ?? 'primary'\"\n    >\n      {{ button.text }}\n    </button>\n  }\n</mat-dialog-actions>\n", styles: ["mat-dialog-actions button{text-transform:uppercase}\n"] }]
        }], ctorParameters: () => [] });

/**
 * Harness for interacting with a dialog opened via {@link SlDialogService.open}.
 */
class SlDialogHarness extends ContentContainerComponentHarness {
    static { this.hostSelector = 'sl-dialog'; }
    #getContent = this.locatorFor('mat-dialog-content');
    /**
     * Gets a `HarnessPredicate` that can be used to search for a SlDialogHarness that meets certain criteria.
     */
    static with(options) {
        return new HarnessPredicate(SlDialogHarness, options).addOption('title', options.title, async (harness, title) => HarnessPredicate.stringMatches(harness.getTitle(), title));
    }
    async getTitle() {
        const title = await this.locatorFor('[mat-dialog-title]')();
        return title.text();
    }
    /**
     * Get the text displayed in the content of the dialog. Note this includes text from both the `text` and `component` options of {@link SlDialogService.open}.
     */
    async getContentText() {
        const content = await this.#getContent();
        return content.text();
    }
    /**
     * Return the text of all the buttons.
     */
    async getButtonText() {
        const buttons = await this.#getButtons();
        return Promise.all(buttons.map(async (button) => button.getText()));
    }
    /**
     * Return the text of all the buttons. Note that "default" corresponds to when you explicitly specify that color for the button, and is **not** the color of a button when you don't specify a color (see {@link DialogButton.color}).
     */
    async getButtonColors() {
        const buttons = await this.#getButtons();
        return Promise.all(buttons.map(async (button) => {
            const host = await button.host();
            if (await host.hasClass('mat-primary')) {
                return 'primary';
            }
            else if (await host.hasClass('mat-accent')) {
                return 'accent';
            }
            else if (await host.hasClass('mat-warn')) {
                return 'warn';
            }
            else {
                return 'default';
            }
        }));
    }
    async clickButton(text) {
        const button = await this.#getButton(text);
        await button.click();
    }
    /**
     * Closes the dialog by pressing escape.
     */
    async close() {
        const rootLoader = await this.documentRootLocatorFactory().rootHarnessLoader();
        const dialog = await rootLoader.getHarness(MatDialogHarness);
        await dialog.close();
    }
    async #getButton(text) {
        const footer = await this.#getFooter();
        return footer.getHarness(MatButtonHarness.with({ text }));
    }
    async #getButtons() {
        const footer = await this.#getFooter();
        return footer.getAllHarnesses(MatButtonHarness);
    }
    async #getFooter() {
        return this.getChildLoader('mat-dialog-actions');
    }
}

/**
 * Import this module to enable use of {@linkcode SlDialogService}
 */
class SlDialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.4", ngImport: i0, type: SlDialogModule, imports: [MatDialogModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogModule, imports: [MatDialogModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogModule, decorators: [{
            type: NgModule,
            args: [{ imports: [MatDialogModule] }]
        }] });

/**
 * Shows simple text dialogs with just a method call, and reduces boilerplate for more complex dialogs.
 *
 * A simple text dialog:
 * ```ts
 * const choice = await slDialogService.open({
 *   text: 'Discard draft?',
 *   buttons: [{ text: 'Cancel' }, { text: 'Discard' }]
 * });
 * if (choice === 'Discard') {
 *   // discard the draft
 * }
 * ```
 *
 * Using a custom component:
 * ```ts
 * @Component({
 *   template: `
 *     <h3>Heading 1</h3>
 *     <p>Paragraph 1</p>
 *     <h3>Heading 2</h3>
 *     <p>Paragraph 2</p>
 *   `
 * })
 * class FancyDialogComponent {}
 *
 * slDialogService.open({
 *   title: 'My title',
 *   component: FancyDialogComponent,
 * });
 * ```
 */
class SlDialogService {
    constructor(matDialog) {
        this.matDialog = matDialog;
    }
    /**
     * Resolves when the dialog is closed. Resolves to the {@link DialogButton.value} of the clicked button, or to `undefined` if the dialog was closed another way (such as clicking off it).
     */
    async open(data) {
        const ref = this.matDialog.open(DialogComponent, {
            data,
            autoFocus: false,
        });
        return firstValueFrom(ref.beforeClosed());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogService, deps: [{ token: i2.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogService, providedIn: SlDialogModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: SlDialogService, decorators: [{
            type: Injectable,
            args: [{ providedIn: SlDialogModule }]
        }], ctorParameters: () => [{ type: i2.MatDialog }] });

/**
 * Returns a predicate to query for `MatButtonHarness` that contains a specific icon. Respects all filter options of `MatButtonHarness` itself, and adds the option to specify the name of an icon which must exist inside the button. If no icon name is specified, finds buttons with any icon.
 *
 * ```ts
 * const saveButton =
 *   await loader.getHarness(matButtonHarnessWithIcon({ name: 'save' }));
 * ```
 */
function matButtonHarnessWithIcon(options) {
    return MatButtonHarness.with(options).add('icon', async (harness) => harness.hasHarness(MatIconHarness.with({ name: options.name })));
}

/**
 * Registers a Material {@link https://material.angular.io/components/icon/overview#icon-sets | icon set} in the default namespace.
 *
 * **WARNING:** The `icons` string you pass in will bypass Angular's security measures! Including untrusted user data will expose your application to XSS security risks!
 *
 * By default, Angular Material configures your app to download font files that include **all** material icons. This is a helper for a technique to:
 *
 * - only download the icons your app uses
 * - eliminate flickering in the UI that otherwise happens before the fonts load
 * - reduce the number of network requests needed to load your app
 *
 * This technique requires you to manually download each icon you use, clean up its SVG source, and paste it into your source code. For example, you might create a file called `icons.ts` that looks like this, which contains two icons:
 * ```ts
 * export const icons = `
 * <svg id="drag_handle"><path d="M20,9H4v2h16V9z M4,15h16v-2H4V15z"/></svg>
 * <svg id="menu"><path d="M3 18h18v-2H3v2zm0-5h18v-2H3v2zm0-7v2h18V6H3z"/></svg>
 * `;
 * ```
 *
 * Then in your `app.config` or `app.module`, include it in your `providers` array like this:
 * ```ts
 * export const appConfig: ApplicationConfig = {
 *   providers: [
 *     provideMatIcons(icons),
 *   ]
 * }
 * ```
 *
 * Finally, display the icons in a template like this, where `svgIcon` matches the `id` you gave it above
 * ```html
 * <mat-icon svgIcon="drag_handle" />
 * <mat-icon svgIcon="menu" />
 * ```
 *
 * To construct the `icons` string using svgs from the material team:
 *
 * 1. Find the icon on https://fonts.google.com/icons.
 * 2. Set the "Optical size" to 24px. You are free to modify other customizations.
 * 3. Download the SVG and paste its contents into your `icons` string.
 * 4. Set an `id` on the `<svg>` tag to the name of the icon.
 * 5. Delete any hard-coded colors (e.g. `fill="#000000"`)
 * 6. At this point your icon should be working. If you care to, you can delete unnecessary attributes from the SVG, such as `xmlns`, `width` and `height`. Experiment to see if anything else can be eliminated.
 */
function provideMatIcons(icons) {
    return {
        provide: APP_INITIALIZER,
        multi: true,
        useFactory: () => {
            const registry = inject(MatIconRegistry);
            const sanitizer = inject(DomSanitizer);
            return () => {
                registry.addSvgIconSetLiteral(sanitizer.bypassSecurityTrustHtml(`<svg><defs>${icons}</defs></svg>`));
            };
        },
    };
}

/*
 * Public API Surface of ng-mat-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DEFAULT_OK_VALUE, SL_DIALOG_DATA, SlDialogHarness, SlDialogModule, SlDialogService, matButtonHarnessWithIcon, provideMatIcons };
//# sourceMappingURL=ng-mat-core.mjs.map
